@@ -2,10 +2,10 @@
 from datetime import datetime
 from urllib.parse import quote
 
-import click
 import humanize
 import rich
 import typer
+from rich.align import Align
 from rich.console import Console
 from rich.panel import Panel
 from rich.table import Table
@@ -13,15 +13,18 @@ from rich.theme import Theme
 from typer import Argument, Option
 
 try:
-    import click_help_colors
-    from click_help_colors import HelpColorsCommand, HelpColorsGroup
+    import rich_click as click
+    from rich_click import RichCommand as Command, RichGroup as Group
 except ImportError:
-    click_help_colors = None
+    import click
+    from click import Command, Group
 
 try:
     import ujson as json
 except ImportError:
     import json
+else:
+    json.JSONDecodeError = ValueError
 
 base_url = "https://pypi.org"
 
@@ -127,28 +130,6 @@ def __color_error_message():
     click.exceptions.UsageError.show = show
 
 
-if click_help_colors is not None:
-
-    class CustomHelpColorsGroup(HelpColorsGroup):
-        def __init__(self, *args, **kwargs) -> None:
-            super().__init__(*args, **kwargs)
-            self.help_headers_color = "red"
-            self.help_options_color = "yellow"
-            self.context_settings = {"help_option_names": ["-h", "--help"]}
-
-    class CustomHelpColorsCommand(HelpColorsCommand):
-        def __init__(self, *args, **kwargs) -> None:
-            super().__init__(*args, **kwargs)
-            self.help_headers_color = "red"
-            self.help_options_color = "yellow"
-
-    Group = CustomHelpColorsGroup
-    Command = CustomHelpColorsCommand
-else:
-    Group = click.Group
-    Command = click.Command
-
-
 class AliasedGroup(Group):
     def get_command(self, ctx, cmd_name):
         rv = click.Group.get_command(self, ctx, cmd_name)
@@ -976,40 +957,51 @@ def information(
             url = f"https://api.github.com/repos/{quote(repo)}"
             with console.status("Getting data from GitHub"):
                 resp = session.get(url)
-            github_data = json.loads(resp.text)
-            if github_data.get("message") and github_data["message"] == "Not Found":
-                metadata.add_row(
-                    Panel(
-                        f"[red underline]Repo Not Found[/]\n[cyan]Link[/]: {url}\n[light_green]Name[/]: {repo}\n",
-                        expand=False,
-                        border_style="green",
-                        title="GitHub",
+            if resp.status_code == 200:
+                github_data = json.loads(resp.text)
+                if github_data.get("message") and github_data["message"] == "Not Found":
+                    metadata.add_row(
+                        Panel(
+                            f"[red underline]Repo Not Found[/]\n[cyan]Link[/]: {url}\n[light_green]Name[/]: {repo}\n",
+                            expand=False,
+                            border_style="green",
+                            title="GitHub",
+                        )
+                    )
+                else:
+                    size = github_data.get("size", -1)
+                    stars = github_data.get("stargazers_count", -1)
+                    forks = github_data.get("forks_count", -1)
+                    issues = github_data.get("open_issues", -1)
+                    metadata.add_row(
+                        Panel(
+                            f"[light_green]Name[/]: [link=https://github.com/{repo}]{repo}[/]\n"
+                            f"[light_green]Size[/]: {size:,} KB\n"
+                            f"[light_green]Stargazers[/]: {stars:,}\n"
+                            f"[light_green]Issues/Pull Requests[/]: {issues:,}\n"
+                            f"[light_green]Forks[/]: {forks:,}",
+                            expand=False,
+                            border_style="green",
+                            title="GitHub",
+                        )
                     )
-                )
             else:
-                size = github_data.get("size", "Unknown")
-                stars = github_data["stargazers_count"]
-                forks = github_data["forks_count"]
-                issues = github_data["open_issues"]
                 metadata.add_row(
-                    Panel(
-                        f"[light_green]Name[/]: [link=https://github.com/{repo}]{repo}[/]\n"
-                        f"[light_green]Size[/]: {size:,} KB\n"
-                        f"[light_green]Stargazers[/]: {stars:,}\n"
-                        f"[light_green]Issues/Pull Requests[/]: {issues:,}\n"
-                        f"[light_green]Forks[/]: {forks:,}",
-                        expand=False,
-                        border_style="green",
-                        title="GitHub",
+                        Panel(
+                            f"Error {resp.status_code}",
+                            expand=False,
+                            border_style="green",
+                            title="GitHub",
+                        )
                     )
-                )
     if not hide_stats:
         stats_url = f"https://pypistats.org/api/packages/{package_name}/recent"
         with console.status("Getting statistics from PyPI Stats"):
             r = session.get(stats_url)
         try:
             parsed_stats = json.loads(r.text)
-            assert isinstance(parsed_stats, dict)
+            if not isinstance(parsed_stats, dict):
+                parsed_stats = None
         except (json.JSONDecodeError, AssertionError, ValueError):
             parsed_stats = None
 
@@ -1092,7 +1084,7 @@ def regex_search(
                 matches.append(f"[link={base_url}/project/{package}]{package}[/]")
         console.print(", ".join(matches))
     else:
-        table = Table(show_header=True, show_lines=True, title=f"Matches for {regex}")
+        table = Table(show_header=True, show_lines=True)
         table.add_column("[purple]No.[/]", style="purple")
         table.add_column("[green]Package[/]")
         table.add_column("[blue]Link[/]", style="cyan")
@@ -1105,6 +1097,7 @@ def regex_search(
                     f"[link={base_url}/project/{package}]{package}[/]",
                     f"{base_url}/project/{package}",
                 )
+        table.title = f"{table.row_count} matches for [#ffffff on #000000]{regex}[/]"
         console.print(table)
         if table.row_count > 50:
             console.print(
